<?php

declare(strict_types=1);

namespace spec\Dedi\SyliusSogenactifPlugin\Payum\Sogenactif\Action;

use Payum\Core\Action\ActionInterface;
use Payum\Core\Request\GetStatusInterface;
use Sylius\Component\Core\Model\PaymentInterface as SyliusPaymentInterface;
use PhpSpec\ObjectBehavior;
use Prophecy\Argument;
use Sylius\Bundle\PayumBundle\Request\GetStatus as RequestGetStatus;

final class StatusSpec extends ObjectBehavior
{
    function let(): void
    {
        $this->shouldImplement(ActionInterface::class);
    }

    function it_should_call_detail_and_request(
        RequestGetStatus $requestGenericPayum,
        SyliusPaymentInterface $payment
    )
    {
        $requestGenericPayum
            ->getFirstModel()
            ->shouldBeCalledTimes(2)
            ->willReturn($payment)
        ;

        $payment
            ->getDetails()
            ->shouldBeCalledOnce()
            ->willReturn([])
        ;

        // IF
        $this
            ->execute($requestGenericPayum)
        ;

        // THEN
        $requestGenericPayum
            ->markFailed()
            ->shouldBeCalledOnce()
        ;
    }


    function it_should_fail_if_not_good_status(
        RequestGetStatus $requestGenericPayum,
        SyliusPaymentInterface $payment
    )
    {
        $requestGenericPayum
            ->getFirstModel()
            ->willReturn($payment)
        ;

        $payment
            ->getDetails()
            ->willReturn(['all_normalized_infos' => ['responseCode' => '00']])
        ;

        // IF
        $this
            ->execute($requestGenericPayum)
        ;

        // THEN
        $requestGenericPayum
            ->markCaptured()
            ->shouldBeCalledOnce()
        ;
    }
}
